Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1689)

Unified Diff: sdk/lib/io/file.dart

Issue 11770004: Rename Date to DateTime. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address comments and keep Backwards-compatibility class Date. Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sdk/lib/indexed_db/dart2js/indexed_db_dart2js.dart ('k') | sdk/lib/io/file_impl.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/io/file.dart
diff --git a/sdk/lib/io/file.dart b/sdk/lib/io/file.dart
index e3be26bcf316c27095c1d9d64e23fe063eb81ceb..53a348c5033a68674a48480ccad6bb5849aee4cf 100644
--- a/sdk/lib/io/file.dart
+++ b/sdk/lib/io/file.dart
@@ -99,16 +99,16 @@ abstract class File {
/**
* Get the last-modified time of the file. Returns a
* [:Future<Date>:] that completes with a [Date] object for the
* modification date.
*/
- Future<Date> lastModified();
+ Future<DateTime> lastModified();
/**
* Get the last-modified time of the file. Throws an exception
* if the file does not exist.
*/
- Date lastModifiedSync();
+ DateTime lastModifiedSync();
/**
* Open the file for random access operations. Returns a
« no previous file with comments | « sdk/lib/indexed_db/dart2js/indexed_db_dart2js.dart ('k') | sdk/lib/io/file_impl.dart » ('j') | no next file with comments »
@@ -99,16 +99,16 @@ abstract class File {
/**
* Get the last-modified time of the file. Returns a
- * [:Future<Date>:] that completes with a [Date] object for the
+ * [:Future<DateTime>:] that completes with a [DateTime] object for the
* modification date.
*/

Powered by Google App Engine
This is Rietveld 408576698